@@ -15,14 +15,14 @@ def _get_kwargs(
     *,
     client: AuthenticatedClient,
     json_body: EnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/environment/import/".format(client.base_url)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     json_json_body = json_body.to_dict()
@@ -62,7 +62,7 @@ def sync_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Import Environment Configuration
 
@@ -70,7 +70,7 @@ def sync_detailed(
     It doesn't delete anything, only adds/updates what was passed to it.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EnvironmentIn):
 
     Returns:
@@ -106,7 +106,7 @@ def sync(
     *,
     client: AuthenticatedClient,
     json_body: EnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Import Environment Configuration
 
@@ -114,7 +114,7 @@ def sync(
     It doesn't delete anything, only adds/updates what was passed to it.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EnvironmentIn):
 
     Returns:
@@ -132,7 +132,7 @@ async def asyncio_detailed(
     *,
     client: AuthenticatedClient,
     json_body: EnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Import Environment Configuration
 
@@ -140,7 +140,7 @@ async def asyncio_detailed(
     It doesn't delete anything, only adds/updates what was passed to it.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EnvironmentIn):
 
     Returns:
@@ -174,7 +174,7 @@ async def asyncio(
     *,
     client: AuthenticatedClient,
     json_body: EnvironmentIn,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> None:
     """Import Environment Configuration
 
@@ -182,7 +182,7 @@ async def asyncio(
     It doesn't delete anything, only adds/updates what was passed to it.
 
     Args:
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
         json_body (EnvironmentIn):
 
     Returns:
