@@ -17,14 +17,14 @@ def _get_kwargs(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/integration/".format(client.base_url, app_id=app_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -72,7 +72,7 @@ def sync_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseIntegrationOut:
     """List Integrations
 
@@ -82,7 +82,7 @@ def sync_detailed(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseIntegrationOut
@@ -121,7 +121,7 @@ def sync(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseIntegrationOut:
     """List Integrations
 
@@ -131,7 +131,7 @@ def sync(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseIntegrationOut
@@ -152,7 +152,7 @@ async def asyncio_detailed(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseIntegrationOut:
     """List Integrations
 
@@ -162,7 +162,7 @@ async def asyncio_detailed(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseIntegrationOut
@@ -199,7 +199,7 @@ async def asyncio(
     client: AuthenticatedClient,
     iterator: Union[Unset, None, str] = UNSET,
     limit: Union[Unset, None, int] = 50,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseIntegrationOut:
     """List Integrations
 
@@ -209,7 +209,7 @@ async def asyncio(
         app_id (str): The application's ID or UID Example: app_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         iterator (Union[Unset, None, str]):  Example: integ_1srOrx2ZWZBpBUvZwXKQmoEYga2.
         limit (Union[Unset, None, int]):  Default: 50.
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseIntegrationOut
