@@ -26,14 +26,14 @@ def _get_kwargs(
     status: Union[Unset, None, MessageStatus] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> Dict[str, Any]:
     url = "{}/api/v1/app/{app_id}/msg/{msg_id}/attempt/".format(client.base_url, app_id=app_id, msg_id=msg_id)
 
     headers: Dict[str, str] = client.get_headers()
     cookies: Dict[str, Any] = client.get_cookies()
 
-    if not isinstance(idempotency_key, Unset):
+    if not isinstance(idempotency_key, Unset) and idempotency_key is not None:
         headers["idempotency-key"] = idempotency_key
 
     params: Dict[str, Any] = {}
@@ -119,7 +119,7 @@ def sync_detailed(
     status: Union[Unset, None, MessageStatus] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts
 
@@ -143,7 +143,7 @@ def sync_detailed(
             - Sending = 3
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -196,7 +196,7 @@ def sync(
     status: Union[Unset, None, MessageStatus] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts
 
@@ -220,7 +220,7 @@ def sync(
             - Sending = 3
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -255,7 +255,7 @@ async def asyncio_detailed(
     status: Union[Unset, None, MessageStatus] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts
 
@@ -279,7 +279,7 @@ async def asyncio_detailed(
             - Sending = 3
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
@@ -330,7 +330,7 @@ async def asyncio(
     status: Union[Unset, None, MessageStatus] = UNSET,
     before: Union[Unset, None, datetime.datetime] = UNSET,
     after: Union[Unset, None, datetime.datetime] = UNSET,
-    idempotency_key: Union[Unset, str] = UNSET,
+    idempotency_key: Union[Unset, None, str] = UNSET,
 ) -> ListResponseMessageAttemptOut:
     """List Attempts
 
@@ -354,7 +354,7 @@ async def asyncio(
             - Sending = 3
         before (Union[Unset, None, datetime.datetime]):
         after (Union[Unset, None, datetime.datetime]):
-        idempotency_key (Union[Unset, str]): The request's idempotency key
+        idempotency_key (Union[Unset, None, str]): The request's idempotency key
 
     Returns:
         ListResponseMessageAttemptOut
