@@ -15,11 +15,13 @@ class ListResponseApplicationOut:
         data (List[ApplicationOut]):
         done (bool):
         iterator (Union[Unset, None, str]):  Example: iterator.
+        prev_iterator (Union[Unset, None, str]):  Example: -iterator.
     """
 
     data: List[ApplicationOut]
     done: bool
     iterator: Union[Unset, None, str] = UNSET
+    prev_iterator: Union[Unset, None, str] = UNSET
     additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)
 
     def to_dict(self) -> Dict[str, Any]:
@@ -31,6 +33,7 @@ class ListResponseApplicationOut:
 
         done = self.done
         iterator = self.iterator
+        prev_iterator = self.prev_iterator
 
         field_dict: Dict[str, Any] = {}
         field_dict.update(self.additional_properties)
@@ -42,6 +45,8 @@ class ListResponseApplicationOut:
         )
         if iterator is not UNSET:
             field_dict["iterator"] = iterator
+        if prev_iterator is not UNSET:
+            field_dict["prevIterator"] = prev_iterator
 
         return field_dict
 
@@ -59,10 +64,13 @@ class ListResponseApplicationOut:
 
         iterator = dict_copy.pop("iterator", UNSET)
 
+        prev_iterator = dict_copy.pop("prevIterator", UNSET)
+
         list_response_application_out = cls(
             data=data,
             done=done,
             iterator=iterator,
+            prev_iterator=prev_iterator,
         )
 
         list_response_application_out.additional_properties = dict_copy
