@@ -2,6 +2,7 @@ from typing import Any, Dict, List, Type, TypeVar, Union, cast
 
 import attr
 
+from ..models.application_in import ApplicationIn
 from ..models.message_in_payload import MessageInPayload
 from ..types import UNSET, Unset
 
@@ -14,6 +15,7 @@ class MessageIn:
     Attributes:
         event_type (str):  Example: user.signup.
         payload (MessageInPayload):  Example: {'email': 'test@example.com', 'username': 'test_user'}.
+        application (Union[Unset, ApplicationIn]):
         channels (Union[Unset, None, List[str]]): List of free-form identifiers that endpoints can filter by Example:
             ['project_123', 'group_2'].
         event_id (Union[Unset, None, str]): Optional unique identifier for the message Example: evt_pNZKtWg8Azow.
@@ -23,6 +25,7 @@ class MessageIn:
 
     event_type: str
     payload: MessageInPayload
+    application: Union[Unset, ApplicationIn] = UNSET
     channels: Union[Unset, None, List[str]] = UNSET
     event_id: Union[Unset, None, str] = UNSET
     payload_retention_period: Union[Unset, int] = 90
@@ -31,6 +34,10 @@ class MessageIn:
     def to_dict(self) -> Dict[str, Any]:
         event_type = self.event_type
         payload = self.payload
+        application: Union[Unset, Dict[str, Any]] = UNSET
+        if not isinstance(self.application, Unset):
+            application = self.application.to_dict()
+
         channels: Union[Unset, None, List[str]] = UNSET
         if not isinstance(self.channels, Unset):
             if self.channels is None:
@@ -49,6 +56,8 @@ class MessageIn:
                 "payload": payload,
             }
         )
+        if application is not UNSET:
+            field_dict["application"] = application
         if channels is not UNSET:
             field_dict["channels"] = channels
         if event_id is not UNSET:
@@ -65,6 +74,13 @@ class MessageIn:
 
         payload = dict_copy.pop("payload")
 
+        _application = dict_copy.pop("application", UNSET)
+        application: Union[Unset, ApplicationIn]
+        if isinstance(_application, Unset):
+            application = UNSET
+        else:
+            application = ApplicationIn.from_dict(_application)
+
         channels = cast(List[str], dict_copy.pop("channels", UNSET))
 
         event_id = dict_copy.pop("eventId", UNSET)
@@ -74,6 +90,7 @@ class MessageIn:
         message_in = cls(
             event_type=event_type,
             payload=payload,
+            application=application,
             channels=channels,
             event_id=event_id,
             payload_retention_period=payload_retention_period,
